aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--bpkg/pkg-build.cxx4
-rw-r--r--bpkg/system-package-manager.hxx8
2 files changed, 7 insertions, 5 deletions
diff --git a/bpkg/pkg-build.cxx b/bpkg/pkg-build.cxx
index 154fde9..ca27770 100644
--- a/bpkg/pkg-build.cxx
+++ b/bpkg/pkg-build.cxx
@@ -1764,14 +1764,10 @@ namespace bpkg
// db and no-db cases consistently.
//
if (sp == nullptr || !sp->authoritative)
- {
- //@@ Also save the system_version to show in the plan?
-
db->system_repository->insert (nm,
*vc->min_version,
true /* authoritative */,
sps);
- }
}
return make_pair (move (*vc), sps);
diff --git a/bpkg/system-package-manager.hxx b/bpkg/system-package-manager.hxx
index 5fe1431..b8511a6 100644
--- a/bpkg/system-package-manager.hxx
+++ b/bpkg/system-package-manager.hxx
@@ -84,8 +84,14 @@ namespace bpkg
//
bpkg::version version;
// System (as in, distribution package) version.
//
+ // Note that this status may represent multiple system packages (for
+ // example, libssl3 and libssl3-dev) and here we have the main package
+ // name (for example, libssl3).
+ //
+ string system_name;
string system_version;
// The system package can be either "available already installed",
@@ -84,8 +84,14 @@ namespace bpkg
//
bpkg::version version;
- // System (as in, distribution package) version.
+ // System (as in, distribution package) package name and version for
+ // diagnostics.
//